
              M.A.M.E.  -  Multiple Arcade Machine Emulator
       Copyright (C) 1997, 1998  by Nicola Salmoria and the MAME team


Notare come molte persone hanno dato un aiuto in questo progetto, direttamente
o liberando il codice sorgente che  stato usato per scrivere i driver.
Non vogliamo appropriarci meriti che non sono nostri. Vedere la sezione dei
ringraziamenti per una lista dei contributori, che comunque  in gran parte
incompleta. Vedere inoltre la sezione di ACCREDITAMENTI nell'emulatore per
vedere le persone che hanno contribuito ad un driver specifico.
Anche questa lista potrebbe essere incompleta. Chiediamo scusa in anticipo per
ogni omissione.

Tutti i marchi citati in questo documento sono di propriet dei loro rispettivi
proprietari. 


Licenza d'uso e distribuzione
-----------------------------

I. Scopo
--------
   MAME  rigorosamente un progetto senza profitto. Il suo scopo principale 
   essere un riferimento ai funzionamenti interni delle macchine arcade emulate.
   Ci  fatto per scopi educativi e per conservare molti giochi storici dall'oblio
   in cui essi affonderebbero quando l'hardware che vi funziona sopra smetter di
   funzionare.
   Naturalmente per conservare i giochi dovete anche poter realmente giocarli; questo
   si pu vedere come un piacevole effetto secondario.
   Non  nostra intenzione infrangere alcun copyright o brevetto di registrazione sui
   giochi originali. Tutto il codice sorgente  di nostra propriet e liberamente
   disponibile. Per funzionare, l'emulatore richiede le ROM delle macchine originali
   arcade, che devono essere fornite dall'utente. Nessuna parte del codice delle ROM
   originali  inclusa nell'eseguibile.

II. Costo
---------
   MAME  libero. Il codice sorgente  libero. Non  permesso venderlo.

III. Immagini della ROM
-----------------------
   Le immagini delle ROM sono materiale protetto da copyright, e la maggior parte
   non  distribuibile liberamente. La distribuzione del MAME sullo stesso mezzo
   fisico insieme a copie illegali di ROM  rigorosamente vietato.
   Non siete autorizzati a distribuire MAME in alcuna forma di vendita, fare pubblicit
   o divulgare CD-ROMs illegali o ad altri media che contengono le immagini delle ROM.
   Notare che le restrizioni si applicano anche se non guadagnate soldi direttamente.
   Siete autorizzati a renderle disponibili per il download sullo stesso sito web,
   ma soltanto se avvertite gli utenti circa le condizioni di copyright delle ROM
   e degli aspetti legali coinvolti. Non vi  consentito rendere disponibile il MAME
   per il download con un grande file contenente alcuna ROM supportata. 
   
IV. Distribuzione del codice sorgente
-------------------------------------
   Se distribuite il binario, dovreste anche distribuire il codice sorgente. Se non
   potete fare questo, dovete fornire un posto in cui la sorgente pu essere ottenuta.

V. Integrit della distribuzione
--------------------------------
   Questo capitolo si applica alla distribuzione ufficiale MAME. Vedere il capitolo
   seguente per le limitazioni della distribuzione di lavori derivati.
   MAME deve essere distribuito soltanto negli archivi originali. Non siete autorizzati
   a distribuire una versione modificata, n rimuovere e/o aggiungere dei files agli
   archivi. 

VI. Riutilizzo del codice sorgente
----------------------------------
   Questo capitolo non si pu applicare a parti specifiche di MAME (per esempio
   emulatori delle CPU) che sopportano gli avvisi di copyright differenti.
   Il codice sorgente non pu essere usato in un prodotto commerciale senza 
   un'autorizzazione scritta degli autori. L'uso in prodotti non commerciali
    permesso ed effettivamente  consigliato; tuttavia se usate delle parti
   del codice sorgente di MAME nel vostro programma, dovete rendere pure il 
   codice sorgente completo liberamente disponibile. Lavori derivati sono
   permessi (il codice sorgente fornito  disponibile), ma sono scoraggiati:
   MAME  un progetto in continua evoluzione, e voi dovete, nel vostro miglior
   interesse, presentare il vostro contributo al team di sviluppo, in modo da
   essere integrato nella distribuzione principale. L' uso _delle informazioni_
   contenute nel codice sorgente  libero per qualsiasi uso. Tuttavia, dato il
   tempo e l'energia che ha preso raccogliere queste informazioni, noi
   apprezzeremmo delle informazioni supplementari che potreste avere. 

VII. Lavori Derivati
--------------------
   Lavori derivati sono permessi (procurarsi il codice sorgente disponibile), 
   MAME  un progetto in continua evoluzione, e tu dovresti, anche nel tuo interesse,
   sottoporre i tuoi contributi al team di sviluppo, cos da essere integrati nella
   distribuzione principale.
   C' un certo numero di driver nei sorgenti che sono disabilitati nella distribuzione
   ufficiale. Attivare questi NON  considerato un lavoro derivato, e la distribuzione
   dell'eseguibile con questi driver attivati  fortemente vietata.

Come mettersi in contatto
-------------------------
   
La home page ufficiale del MAME  http://mame.retrogames.com/. Qui puoi trovare
sempre le ultime release ufficiali, le beta, informazioni e anticipazioni.

http://www.volftp.tin.it/ludus/iep/imame/ invece  l'home page dell'imame.
Consiglio vivamente di inserire nei vostri bookmark I.E.P., sicuramente uno dei
migliori siti sull'emulazione esistenti nel web....e poi  in italiano :-) 


Qui ci sono alcune delle persone che contribuiscono al MAME. Se avete
osservazioni, suggerimenti o segnalazioni di bug circa un driver attuale,
controllate la sezione di accreditamenti dei driver per trovare chi ha
lavorato ad esso e per inviare le osservazioni a quella persona. Se non
siete sicuri con chi mettersi in contatto, scrivete a Nicola.

OVVIAMENTE SE IL PROBLEMA O IL SUGGERIMENTO RIGUARDA L'IMAME SCRIVETE AL SOTTOSCRITTO:
Maurizio Clementini     imorriz@tin.it

Se avete osservazioni specifiche ad un sistema tranne il DOS (per esempio
mac, Win32, UNIX), dovrebbero essere trasmesse al mantenitore del rispettivo
port. NON TRASMETTERLE A MIRKO O A NICOLA - saranno ignorate. 

Potete trasmettere il codice sorgente a mame@lim.dsi.unimi.it. Non usare
questo indirizzo per segnalazioni di bug di codice non-sorgente. 

Nicola Salmoria    MC6489@mclink.it

Mike Balfour       mab22@po.cwru.edu
Aaron Giles        agiles@sirius.com
Chris Moore        chris.moore@writeme.com
Brad Oliver        bradman@primenet.com
Andrew Scott       ascott@utkux.utcc.utk.edu
Zsolt Vasvari      vaszs01@banet.net

NON TRASMETTERE ATTACHMENTS DI BINARI SENZA CHIEDERE PRIMA, *IN PARTICOLARE* IMMAGINI DELLE ROM. 

QUESTI NON SONO INDIRIZZI DI SUPPORTO. Domande di supporto trasmesse a questi
indirizzi possono essere ignorate. Si prega capire che questa  progetto libero,
principalmente designato ad utenti con esperienza. Non disponiamo dei mezzi per
fornire il supporto all' utilizzatore finale. Praticamente, se non riuscite a far 
funzionare l'emulatore, sono problemi vostri. Prima di tutto, leggere con 
attenzione i documenti. Se voi ancora non trovate un risposta alle vostre domande,
provate controllando le sezioni per principianti sulle pagine dell'emulazione,
o chiedete su un newsgroup USENET adatto (per esempio it.comp.emulatori) o la
message board ufficiale del MAME, http://www.macmame.org/wwwboard/mame /.

Per aiuti sulla compilazione del MAME, controlla queste pagine:
http://seagate.cns.net.au/~ben/emu/compilemame.html (inglese)
http://zan.emuunlim.com/mame/compile/compilemamebeta.html (inglese)
oppure la stupenda guida su I.E.P. completamente in italiano:
http://volftp.tin.it/ludus/iep/faq/arcade/mame_compile/mame_compile.htm

Inoltre, NON TRASMETTERE RICHIESTE DI NUOVI GIOCHI DA AGGIUNGERE, a meno che voi
abbiate informazioni certe sull' hardware del gioco o, persino migliorate,
possedete la scheda e fate una perizia tecnica per aiutare.
Si prega di non trasmetterci informazioni ampiamente disponibili si Internet,
siamo perfettamente capaci di individuarle noi stessi, grazie.

Ringraziamenti
--------------

Prima di tutto, grazie a Allard van der Bas (avdbas@wi.leidenuniv.nl) per aver
avviato l' Arcade Emulation Programming Repository (deposito di programmazione
sull'emulazione dell'arcade)a http://valhalla.ph.tn.tudelft.nl/emul8.
Senza il repository, non si sarebbe persino mai provato a scrivere un emulatore.
Purtroppo, il Repository originale ora  chiuso, ma il relativo spirito vive nel MAME. 

Z80 emulatore Copyright (c) 1998 Juergen Buchmueller, tutti i diritti riservati.
M6502 emulatore di Juergen Buchmueller.
Hu6280 Copyright (c) 1999 Bryan McPhail, mish@tendril.force9.net
I86 emulatore di David Hedley, modificato da Fabrice Frances (frances@ensica.fr)
M6809 emulatore di John Butler, basato su L.C. Benschop's 6809 Simulatore V09.
M6808 basato su L.C. Benschop's 6809 Simulatore V09.
80x86 asm emulatore M6808 Copyright 1998, Neil Bradley, Tutti i diritti riservati.
M68000 emulatore preso dal System 16 Arcade Emulator di Thierry Lescot.
8039 emulatore di Mirko Buffoni, basato sull'emulatore 8048 di Dan Boris.
T-11 emulatore Copyright (C) Aaron Giles 1998
TMS34010 emulatore di Alex Pasadyn e Zsolt Vasvari.
TMS9900 emulatore di Andy Jones, basato sul codice originale di Ton Brouwer.
Cinematronics CPU emulatore di Jeff Mitchell, Zonn Moore, Neil Bradley.
Atari AVG/DVG emulatore basato su VECSIM by Hedley Rainnie, Eric Smith and
Al Kossow.

TMS5220 emulatore di Frank Palazzolo.
AY-3-8910 emulazione basata sui vari pezzi di codice di Ville Hallik,
  Michael Cuddy, Tatsuyuki Satoh, Fabrice Frances, Nicola Salmoria.
YM-2203 e YM-2151 emulazione di Tatsuyuki Satoh.
POKEY emulatore di Ron Fries (rfries@aol.com).
Molti ringraziamenti a Eric Smith, Hedley Rainnie e Sean Trowbridge per le
   informazioni sul generatore di numero casuale di Pokey.
NES informazioni sull'hardware sonoro di Jeremy Chadwick e Hedley Rainne.
YM3812 e YM3526 emulazione di Carl-Henrik Skrstedt.
YM2610 emulazione di Hiromitsu Shioya.

Background art di Peter Hirschberg (PeterH@cronuscom.com).

Allegro librerie di Shawn Hargreaves, 1994/97
SEAL Synthetic Audio Library API Interface Copyright (C) 1995, 1996
   Carlos Hasan. Tutti i diritti riservati.
Video modi creati usando Tweak 1.6b di Robert Schmidt, che ha anche scritto
   TwkUser.c.
Codice "inflate" per il supporto dei file zip di Mark  Adler.

Grandi ringraziamenti a Gary Walton (garyw@excels-w.demon.co.uk) per troppe
   cose da non poterle accennare tutte.

Grazie a Brian Deuel, Neil Bradley e il Retrocade dev team per permetterci
di usare il Retrocade's game history database. [John Butler]



Uso
---

MAME [nome del gioco da far partire] [opzioni] 

per esempio 

MAME mspacman -soundcard 0   far partire Ms Pac Man senza suono



opzioni:
-tweak/-notweak (predefinito: notweak)
              MAME supporta un largo numero di modi tweaked VGA, con risoluzioni
              adeguate per i giochi emulati. Questi modi assomigliano molto per la
              qualit ai modi VESA (solitamente veloci), per possono avere
              problemi di compatibilt con alcune schede grafiche e monitor, quindi
              non sono attivi di default. Tu dovresti cercare a tutti i costi di usare
              -tweak se il tuo hardware lo supporta. Notare che alcuni modi possono 
              funzionare e altri no. es: la tua scheda grafica supporta 256x256 ma non
              384x224. In tal caso devi accendere o spegnere -tweak a seconda del gioco
              vuoi far partire. -noscanlines pu risolvere molti problemi di compatibilit.
-ntsc         il 288x224  un modo con le frequenze standard NTSC. Avete bisogno
              d'un certo hardware supplementare (convertitore di VGA2TV) per usarlo.
-vesamode vesa1/vesa2b/vesa2l/vesa3
	      Forza il modo VESA da usare. Quello predefinito  il migliore disponibile.
              Alcune schede grafiche vanno in crash durante l'auto riconoscimento,
              se hai questo problema, puoi provare con degli standard inferiori (parti
              con vesa1 e aumenti fino a qando non si ripresenta il problema).
-resolution XxY
              dove X e Y sono larghezza ed altezza (ex: '-risolution 800x600')
              MAME ha alcune lunghezze di autoselezione per una buona risoluzione.
              Potete escludere la scelta del MAME con questa opzione.
              Potete usare -XxY (per esempio -800x600) come scorciatoia. Gli autori
              del Frontend si raccomandano di usare -resolution XxY, tuttavia.
-skiplines N / -skipcolumns N
              se voi fate partire un gioco con un modo video in cui la zona
              visibile  piccola, voi potete regolare la relativa posizione
              usando  i tasti PGUP e PGDN (da solo per il panning verticale,
              con shift per il panning orizzonatale).
              Potete anche usare questi due parametri per regolare la posizione
              iniziale: 0  il predefinito, mantiene lo schermo centrato.
              Potete specificare sia il negativo che il positivo delle immagini.
-scanlines/-noscanlines (predefinito: -scanlines)
              se il modo predefinito non funziona con la vostra scheda monitor/video
              (doppia immagine/quadro schiacciato verticalmente), usa -noscanlines o
              -vesa.
-stretch/-nostretch (predefinito: stretch)
              Usa -nostretch per disabilitare i pixel doppi neo modi VESA (pi veloce,
              ma immagini pi piccole).
-depth n      (predefinito: 16)
              Alcuni giochi hanno bisogno dei modi di colore a 65k per ottenere
              una grafica accurata. Per migliorare la velocit, potete aggirare
              questo usando -depth 8, che limita ai modi standard con 256 colori.
-gamma n      (predefinito: 1.2)
              Per regolare il valore gamma iniziale di correzione.
-vgafreq n    dove la n pu essere 0 (predefinito) 1, 2 o 3.
              usa frequenze differenti per i video modi consueti. Questo ha potuto
              ridurre la luce intermittente, particolarmente nel modo
              224x288noscanlines. ATTENZIONE: LE FREQUENZE USATE POSSONO ESSERE
              FUORI DALLA GAMMA DEL VOSTRO VIDEO E POTREBBE ANCHE DANNEGGIARLO.
              USA QUESTE OPZIONI A TUO RISCHIO.
-vsync/-novsync (predefinito: -novsync)
              sincronizza la video visualizzazione con il fascio video invece di
              usare il temporizzatore. Questa opzione pu essere usata soltanto
              se il modo video selezionato ha un adatta velocit di refresh;
              il MAME al contrario si rifiuta di partire, dicendovi la reale
              velocit di refresh del modo video ed il tasso che dovrebbe avere.
              Se state usando un modo tweaked, MAME prover a selezionare
              automaticamente la regolazione corretta per il -vgafreq; potete
              escluderli usando ancora l' opzione -vgafreq.
              Nota: il modo 224x288 noscanlines non lavora con la maggior parte
              delle schede. Questo modo  usato da molti giochi, per esempio
              Pac Man e Galaga. Se con la vostra scheda non funziona, usare la
              versione scanlines, o non usare il -vsync.
              Se state usando un modo VESA dovreste usare il programma che vie
               stato dato con la vostra scheda video per regolare la velocit
              adatta di refresh. Si noti che quando questa opzione  attiva,
              la velocit non retroceder piacevolmente se il vostro sistema non
               abbastanza veloce (cio: gameplay pi a scatti).
-alwayssynced/-noalwayssynced (predefinito: - noalwayssynced)
              per molti modi tweaked di VGA, MAME ha due definizioni: uno che 
              pi compatibile, ed uno che  meno compatibile ma usano le frequenze
              compatibili con -vsync. Per il predefinito, la definizione meno
              compatibile  usata soltanto quando il -vsync  chiesto; usando
              questa opzione, potete forzarlo
              per essere sempre usato.
-triplebuffer/-notriplebuffer (predefinito: -notriplebuffer)
              Attivare il triple buffering con i modi VESA. Questo  pi veloce di
              -vsync, che non funziona con tutte le schede grafiche, e rimuove gli 
              strappi durante lo scrolling.
-monitor NNNN (predefinito: standard)
              seleziona il tipo di monitor:
              standard: standard PC monitor
              ntsc:     NTSC monitor
              pal:      PAL monitor
              arcade:   arcade monitor
-centerx N and -centery N
              prendere e segnarsi il valore (da -8 a 8 per centerx, da -16 a 16 per
              centery) e assegnare questo in base al monitor (monitor=ntsc,pal,arcade)
-waitinterlace
              forza l'aggiornamento per i vari monitor (monitor=ntsc,pal,arcade).
              
-ror          ruota il display di 90 gradi in senso orario.
-rol          ruota il display in senso antiorario.
-flipx        spostare leggermente il display orizzontalmente
-flipy        spostare leggermente il display verticalmente
              -ror e -rol forniscono l'autentico scanlines verticale, in
              questo caso dovete girare il monitor sul relativo lato.
              AVVERTIMENTO:
              Un monitor  un dispositivo elettronico complicato e ad alta
              tensione. Ci sono alcuni monitor che sono stati predisposti
              per essere ruotati. Se il vostro NON  uno di questi, ma
              dovete assolutamente girarlo sul relativo lato, lo fate a
              vostro rischio.
              ***********************************************************
              SI PREGA DI NON LASCIARE IL VOSTRO MONITOR SENZA ATTENZIONE
              SE E' ACCESO ED E' GIRATO SUL RELATIVO LATO
              ***********************************************************

-norotate     Questo comando disabilita tutte le rotazioni interne dell'immagine,
              visualizzando quindi l'uscita video come essa  (in questo modo
              avete bisogno di un monitor verticale per vedere i giochi verticali).
              Tuttavia, molti driver ancora non usano la rotazione centralizzata MAME,
              ma preferibilmente ruotano l' immagine da s, il modo -norotate non ha
              effetto su di loro. In alcuni casi, l'immagine sar inversa. Per
              correggere questo, usare -norotate -flipx -flipy.

-frameskip n (predefinito: auto)
	      salta i frames per accellerare l'emulazione. n  il numero dei frames da
	      saltare e pu arrivare a 12. Per esempio, se il gioco funziona normalmente
              a 60 fps, "-frameskip 2" lo far funzionare a 50 fps e "frameskip 6" a 30
              fps. Usa F11 per controllare la velocit che il tuo computer realmente sta
              raggiungendo. Se  sotto il 100% aumentare il valore del frameskip.
	      Puoi premere F8 per cambiare il frameskip durante il gioco.
              Quando  settato su auto (predefinito), il settaggio del frameskip  
	      regolato al massimo possibile anche se st sotto il 100%
-antialias/-noantialias (predefinito: -antialias)
              antialiasin per i giochi vettore
-beam n       regola la larghezza in pixels dei vettori. n  il valore della gamma e va
              da 1.00 a 16.00.
-flicker n    produce la luce intermittente dei vettori. n  un valore della gamma
              opzionale, e va da 0.00 a 100.00 (0=nessuno 100=massimo).
-translucency/-notranslucency (predefinito: -translucency)
              abilita o disabilita la traslucidit dei vettori.
-soundcard n  seleziona la scheda sonora (se questa non  specificata, vi sar chiesta
              all'avvio del MAME)
-sr n         fissa il tasso del campione audio. Il predefinito  22050. I pi piccoli
              valori (per esempio 11025) causeranno un peggioramento della qualit audio
              ma aumenteranno la velocit di emulazione. I valori pi alti (per esempio
              44100) causeranno una qualit dell'audio migliore ma la velocit di
              emulazione sar pi lenta.
-sb n         fissa i bit del campione audio, 8 o 16. Il predefinito  8. 16 aumenteranno
              la qualit con determinati giochi, ma fanno diminuire la velocit. Ci 
              una regolazione del software, non hardware. La scheda sana sar usata
	      sempre in un modo 16 bit, se possibile.
-stereo/-nostereo (predefinito: -stereo)
              attiva l'uscita stereo per i giochi che lo supportano.
-volume n     (predefinito: 0) imposta il volume di partenza. Tu puoi cambiarlo
              successivamente usando l'On Screen Display. Il volume si attenua in dB,
              es: "-volume -12" se vuoi che parta con l'attenuazione di -12dB.
-ym3812opl/-noym3812opl (predefinito: -ym3812opl) usa il chip SoundBlaster OPL per
              l'emulazione della musica del chip YM3812. Questo  pi veloce e 
              abbastanza accurato poich i chip sono 100% compatibili. Tuttavia,
              la potenza e l'altezza del suono  errata. Notare inoltre che
              con -no3812opl avete bisogno di alcuni campioni esterni del tamburo.

-joy n (predefinito:none) permette di selezionare il joystick, n pu essere:
              0/none       - no joystick
              1/standard   - joystick normale a due pulsanti
              2/dual       - doppio joystick
              3/button4    - Stick/Pad con 4 pulsanti
              4/button6    - Stick/Pad con 6 pulsanti
              5/button8    - Stick/Pad con 8 pulsanti
              6/fspro      - CH Flightstick Pro
              7/wingex     - Wingman Extreme
			   - Wingman Warrior senza spinner
              8/sidewinder - Microsoft Sidewinder (fino a un massimo di 4)
              9/gamepadpro - Gravis GamePad Pro
	      sneslpt1     - SNES pad su LPT1 (necessita di un hardware speciale)
              sneslpt2     - SNES pad su LPT2 (necessita di un hardware speciale)
              sneslpt3     - SNES pad su LPT3 (necessita di un hardware speciale)
 
	      Note:
              1) Usa il TAB menu per calibrare i joysticks analogici. I dati sulla
              calibratura saranno salvati in mame.cfg. Se state usando diversi tipi
              di joysticks per giochi differenti, potete aver bisogno di ricalibrare
              sempre il joystick.
	      2) La descrizione del joystick con il numero non sar supportata sulle
              future versioni del MAME. Usa invece il nome simbolico.
	      3) I pulsanti Extra del noname joysticks potrebbero non funzionare.
	      4) the "official" Snespad-Support site is
              	http://snespad.emulationworld.com

-log          Crea un log con gli accessi illegali alla memoria in ERROR.LOG
-help, -?     visualizza la versione corrente del MAME e informazioni sul copyright
-list         visualizza una lista con i giochi attualmente supportati
-listfull     visualizza una lista dei nomi delle directory dei giochi + descrizione
-listroms     visualizza le roms che il gioco selezionato richiede
-listsamples  visualizza i samples che il gioco selezionato richiede
-listdetails  visualizza una lista dettagliata con i drivers e l'hardware da essi usati
-listgames    lista dei giochi supportati, anno, fabbricante
-listinfo     lista particolarmente completa per tutti i giochi supportati
-listclones   lista di tutti i cloni del gioco specificato
-verifyroms   controlla i giochi selezionati per ROM mancanti o non valide
-verifysamples controlla i giochi selezionati per samples mancanti
-romdir       specifica un nome alternato di directory/zip dove caricare le ROMs per il
              gioco specificato. Per esempio "mame pacman -romdir pachack" far partire
              il driver del Pac Man ma caricher le roms dalla directory del "pachack"
              o dal file "pachack.zip".
-mouse/-nomouse (predefinito: -mouse) abilitare/disabilitare il supporto del mouse
-cheat        Cheats come lo speedup nel Pac Man o il salto di livello in molti altri
              giochi sono disabilitate per predefinito. Utilizzare questo comando per
              attivarle.
-debug        Attiva il debugger integrato. Durante l'emulazione, premere la tilde per
              entrare nel debugger. Questo  disponibile solo se il programma  stato
              compilato con il MAME_DEBUG definito.
-profiler     abilit il profilo. Premese Shift+F11 per mostralo sullo schermo.
-record name   Registra gli input del joystick nel file INP/nome.inp.
-playback name esegue gli input del joystick dal file INP/nome.inp.
-savecfg      al momento non  pi supportato
-ignorecfg    ignora il mame.cfg e parte con il settaggio predefinito


Tasti
-----
Tab          Interruttore del menu di configurazione
Tilde (\)    Interruttore dell'On Screen Display
P            Pausa
F3           Reset
F4           Visualizza i grafici del gioco. Usa i tasti direzionali per cambiare il
             set/color, F4 o Esc per ritornare all'emulazione.
F9           Cambia il frame skip all'istante (60, 30, 20, o 15)
F10          Interruttore limitarore di velocit
F11          Interruttore visualizzazione della velocit
F12          Salva uno snapshot (fotografia) dello schermo. La directory predefinita
             dove verr salvato  PCX, se la cartella non esiste non sar creato.
ESC          Esci dall'emulatore